@@ -17,6 +17,8 @@ class SQLLexer(Lexer):
 
         JOIN, INNER_JOIN, OUTER_JOIN, CROSS_JOIN, LEFT_JOIN, RIGHT_JOIN, FULL_JOIN, ON,
 
+        UNION, ALL,
+
         # Special
         COMMA, LPAREN, RPAREN, PARAMETER,
 
@@ -27,7 +29,7 @@ class SQLLexer(Lexer):
         IN, LIKE, CONCAT, BETWEEN, WINDOW,
 
         # Data types
-        CAST, ID, INTEGER, FLOAT, STRING, NULL, TRUE, FALSE }
+        CAST, ID, INTEGER, FLOAT, STRING, NULL, TRUE, FALSE}
 
 
     # SELECT
@@ -58,6 +60,9 @@ class SQLLexer(Lexer):
     RIGHT_JOIN = r'\bRIGHT JOIN\b'
     FULL_JOIN = r'\bFULL JOIN\b'
 
+    UNION = r'\bUNION\b'
+    ALL = r'\bALL\b'
+
     # Special
     COMMA = r','
     LPAREN = r'\('
@@ -91,7 +96,7 @@ class SQLLexer(Lexer):
     TRUE = r'\bTRUE\b'
     FALSE = r'\bFALSE\b'
 
-    @_(r'([a-zA-Z][a-zA-Z_.0-9]*)|(`([a-zA-Z0-9][^`]*)`)(\.(([a-zA-Z][a-zA-Z_.0-9]*)|(`([a-zA-Z0-9][^`]*)`)))*')
+    @_(r'([a-zA-Z_][a-zA-Z_0-9]*|`([^`]+)`)(\.([a-zA-Z_][a-zA-Z_.0-9]*|`([^`]+)`))*')
     def ID(self, t):
         return t
 
